# Example

Example of a package

- Device addresses: 16, 32, 48
- Address type 7-bit

### Addr 0 8-bytes | # Read-only fields for RegisterA ## This is a few bits ### [7:4] | 4-bytes Read-only | # Write-only fields for RegisterA ## This is fewer bits ### [3:2] | 2-bytes Write-only | # Read/write field for RegisterA ## A single-bit ### [1:1] | 1-byte | # This field should never appear ## A bit that is neither readable nor writeable ### [0:0] | 1-byte Inaccessible
### Addr 1 16-bytes | # Second example ## A 16-bit register |
### Addr 2 32-bytes | # Third example ## A 32-bit register
### Addr 3 0-bytes | # Fourth example ## A dummy register that has no data |

## Functions

- _lifecycle.Begin - Enables features on device
- _lifecycle.End - Enables features on device
- Return.Array - Computes and returns
- Return.Number - Computes and returns
- Return.Void - Computes and returns